@@ -7,7 +7,7 @@ use vars qw($VERSION @ISA);
 require DynaLoader;
 
 @ISA = qw(DynaLoader);
-$VERSION = '1.00';
+$VERSION = '1.02';
 
 bootstrap FFI $VERSION;
 
@@ -139,7 +139,7 @@ Possibly, improve support for passing pointers to "native" types.
 =head1 LICENSE
 
 Substantial portions of the code for this module (the underlying FFI code) are
-licensed under the Gnu General Public License. Under the terms of that
+licensed under the GNU General Public License. Under the terms of that
 license, my understanding is that this module has to be distrubuted under that
 same license.
 
@@ -147,13 +147,25 @@ My personal preference would be to distribute this module under the same terms
 as Perl. However, I understand that this is not possible, given the licensing
 of the FFI code.
 
+=head1 STATUS
+
+This is a maintenance release. We will be releasing an updated but
+incompatible 2.00 version shortly.
+
 =head1 AUTHOR
 
-Paul Moore, gustav@morpheus.demon.co.uk
+Paul Moore, C<< <gustav@morpheus.demon.co.uk> >> is the original author
+of L<FFI>.
+
+Mitchell Charity C<< <mcharity@vendian.org> >> contributed fixes.
+
+Anatoly Vorobey C<< <avorobey@pobox.com> >> and Gaal Yahas C<<
+<gaal@forum2.org> >> are the current maintainers.
 
 =head1 SEE ALSO
 
-http://clisp.cons.org/~haible/clisp.html
+L<http://directory.fsf.org/ffcall.html>
+
 Bruno Haible's CLisp Common Lisp implementation, from which the underlying
 foreign function interface code was taken.
 
